@@ -6,7 +6,7 @@
 #include "math.h"
 #include "mathematics.h"
 #include "randgenerator.h"
-#include "Print.h"
+//#include "Print.h"
 
 
   
@@ -312,7 +312,7 @@ void GIBBS_sumpred_txt_gp(int *aggtype, double *flag, int *its, int *burnin,
 // The programme for GIBBS SAMPLING with XB and missing values
 void GIBBS_gp(double *flag, int *its, int *burnin,
      int *n, int *T, int *r, int *rT, int *p, int *N, int *report,
-     int *cov, int *spdecay, double *shape_e, double *shape_eta,   
+     int *cov, int *spdecay, int *ft, double *shape_e, double *shape_eta,   
      double *phi_a, double *phi_b,
      double *prior_a, double *prior_b, double *prior_mubeta, 
      double *prior_sigbeta, double *prior_omu, double *prior_osig,
@@ -425,8 +425,21 @@ void GIBBS_gp(double *flag, int *its, int *burnin,
           if(i >= brin){    
           oo[0] = op[j];
           mvrnormal(constant, oo, sig_e1, constant, ot);  
-          mn_rep[j] += ot[0];
-          var_rep[j] += ot[0]*ot[0];
+          // Three options: ft: 0=NONE, 1=SQRT, 2=LOG
+		  if(ft[0]==0){
+              mn_rep[j] += ot[0];
+              var_rep[j] += ot[0]*ot[0];
+		  }
+		  else{
+			  if(ft[0]==1){
+              mn_rep[j] += ot[0]*ot[0];
+              var_rep[j] += ot[0]*ot[0]*ot[0]*ot[0];
+			  }
+			  else{
+              mn_rep[j] += exp(ot[0]);
+              var_rep[j] += exp(ot[0])*exp(ot[0]);
+			  }
+		  }
           }
      }
 
@@ -469,7 +482,6 @@ void GIBBS_gp(double *flag, int *its, int *burnin,
           zlt_mean_sd[j] = mn_rep[j];
           zlt_mean_sd[j+N1] = sqrt(var_rep[j]);
      }
-
 // pmcc          
      for(j=0; j < N1; j++){
          if (flag[j] == 1.0){
